Coverage for /home/lvcong/PythonProjects/sanic-restful/sanic_restful/exceptions.py: 100%

# Coverage for /home/lvcong/PythonProjects/sanic-restful/sanic_restful/exceptions.py : 100%

## 7 statements 7 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 | from sanic.exceptions import SanicException, add_status_code @add_status_code(405) class MethodNotAllowed(SanicException): pass @add_status_code(406) class NotAcceptable(SanicException): pass